function Setup_SMx( smxID, pattern)
%% Plays a pattern on the Signal Generator (SigGen)
% copy 64 bits to the SigGen, apply 2PSK modulation. Frequency and level are
% defined in a global variable settings.
% settings.frequency = '2.45GHz';
% settings.level = '-10dBm';
%
% exemplary use: playFile([1 0 0 0 1 0 0 1 1 1 0], 'smbv100a259234')
global settings;

if length(pattern) > 64
    pattern = pattern(1:64);
end
% create a pattern string containing only 1 and 0
pattern = mat2str(pattern);
pattern = pattern(pattern=='0' | pattern=='1');

% Initialize a waitingbar
h = waitbar(0.1, ['Setting up ' smxID]);

[~, deviceObj] = rs_connect('tcpip', smxID);
rs_send_command(deviceObj, 'SOURce:BB:DM:PRESet');              % Preset Baseband
rs_send_query(deviceObj, '*OPC?');
waitbar(0.3, h);

rs_send_command(deviceObj, ['SOURce:FREQuency ' settings.frequency]);   % set frequency 
rs_send_command(deviceObj, ['SOURce:POW ' settings.level]);             % set level

rs_send_command(deviceObj, 'SOURce:BB:DM:CODing OFF');          % Coding OFF
rs_send_command(deviceObj, 'SOURce:BB:DM:FORMat BPSK' );         % BPSK modulation

rs_send_command(deviceObj, 'SOURce:BB:DM:SOURce PATTern');      % Data Source is pattern
rs_send_command(deviceObj, ['SOURce:BB:DM:PATTern #B' ...       % copying pattern to SMBV
    , pattern, ',' num2str(length(pattern))]);
rs_send_command(deviceObj, 'SOURce:BB:DM:Filt:TYPE RECT');      % rectangular pulse shaping

rs_send_command(deviceObj, 'BB:DM:TRIG:OUTP1:MODE PATT');       % Create Marker 1 Output for FSx
rs_send_command(deviceObj, ...
    ['BB:DM:TRIG:OUTP1:PATT #B0000000000001,13']);

rs_send_command(deviceObj, 'BB:DM:TRIG:OUTP2:MODE PATT');       % Create Marker 2 Output for FSx
rs_send_command(deviceObj, ...
    ['BB:DM:TRIG:OUTP2:PATT #B0000000000001,13']);

waitbar(0.7, h);
rs_send_command(deviceObj, 'SOURce:BB:DM:STATe ON');            % switch BB signal ON

rs_send_command(deviceObj, 'OUTPut ON');                        % switch RF signal ON
rs_send_query(deviceObj, '*OPC?');
clear  deviceObj;
close(h);
end

